@@ -3,6 +3,8 @@
 
 require("semtree")
 require("lavaan")
+require("future")
+plan(multisession)
 
 # ORGANIZE DATA BY TYPE FOR COVARIATES.
 # SOME COVARIATES ARE ORGANIZED IN THE DATA. MODEL VARIABLES AND 
